@@ -7,6 +7,7 @@ import click
 import os
 import json
 import importlib.metadata as metadata
+
 __version__ = metadata.version("guetwifi")
 _path = os.path.dirname(os.path.abspath(__file__))
 _runner = "guetwifirunner"
@@ -24,6 +25,7 @@ def _get_pid():
             pass
     return runner_pids
 
+
 def _start():
     runner_pids = _get_pid()
     if runner_pids:
@@ -107,25 +109,6 @@ def status():
     click.echo("guetwifi is not running")
 
 
-@guetwifi.command()
-def upgrade():
-    """Upgrade guetwifi"""
-    click.echo("Upgrade guetwifi...")
-    stop()
-    cmd = "pip install guetwifi --upgrade"
-    subprocess.Popen(cmd, shell=True)
-    start()
-
-
-@guetwifi.command()
-def uninstall():
-    """Uninstall guetwifi"""
-    click.echo("Uninstall guetwifi...")
-    stop()
-    cmd = "pip uninstall guetwifi"
-    subprocess.Popen(cmd, shell=True)
-
-
 @guetwifi.command()
 @click.option("-a", "--account", default=None, help="Your GUET-WIFI account")
 @click.option("-p", "--password", default=None, help="Your GUET-WIFI password")
@@ -141,8 +124,10 @@ def config(account, password, operator):
     with open(config_path, "w") as f:
         json.dump(config, f)
 
+
 def main():
     guetwifi()
 
+
 if __name__ == "__main__":
     guetwifi()
